# Changelog

<!--next-version-placeholder-->

## v0.0.2 (2022-06-21)
### Fix
* Active atom indexing ([`016884d`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/016884dae85e85b2043fc110e9004d5e5e60c490))

## v0.0.1 (2022-06-09)
### Feature
* Add max_analytic_order argument ([`efa7dcc`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/efa7dcc13746e3c8d6cffcd828597d10cbc2191f))
* Add progress print out ([`0ab266c`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/0ab266cb375a5407dd1d079ab606f55be7bf48cb))
* Add max_analytic_order argument ([`7da26f0`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/7da26f05d34108422d68496feeacff50ccffc1f8))
* Add progress print out ([`37f9afd`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/37f9afdb6fc76149a0f7be8d15069340bb48ecf4))
* Support of active atoms in the coupling calculation ([`aa7a94c`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/aa7a94cff6dac1633119c58df6457c8fa8ea843b))
* Gradient norm and invariance printing ([`46def28`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/46def28acdb81b268abc26ab6b26e2853f727ff2))
* Implement prep tau part ([`99cbc8e`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/99cbc8e90b33b9ed15087d5fdd55e9cb411150ca))
* Enable choice to project out translations and rotations ([`00a4b59`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/00a4b59209ccd42d729f3aa18a235e83b84b554d))
* Setup of vibration database ([`d6a4ae3`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/d6a4ae3bdd5f862b145ff62be520cfdede859053))
* Add hessian matrix diagonalisation code ([`6406e2c`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/6406e2c224285bc81883954b66a146b15ea14d95))
* Add hessian diagonalisation code for force constants ([`0795e13`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/0795e138aade65752aa21aac5905e93b10b0144d))
* Add alaska options for lvc inputs ([`ce85501`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/ce8550103005679f4701b83ea66378c19cb4b36a))
* Add mclr option ([`6e300c0`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/6e300c08da93e52d15b6dd63cac76a3e80e56667))
* Add user argument for number of rassi states replacing hard coded Dy ([`947d66d`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/947d66d520daa2bc7ebf731b20fef0ad40eca7db))
* Add multiplicity to `molecules` argument ([`3de7960`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/3de79607d1a236dcc8bc3fda18e40c6e69a415a6))

### Fix
* Correct handling of max_order arguments ([`76826b8`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/76826b875b864d412eaefc45f54e05f0e870087c))
* Minor updates ([`ce42f1b`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/ce42f1bb57679248392921c575c6abab85ac0fb0))
* Input_generator bug ([`220339a`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/220339a4f178065052af36db18b63aba465a0e5b))
* Minor updates ([`39b96aa`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/39b96aa4cb3d06226eabdf7ce21e29c892bde002))
* Input_generator bug ([`bcf8060`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/bcf80603502c55ebef9a8c6776e0d71b985c7345))
* Verbose matrix printing bug ([`70a304a`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/70a304a388775fd1b4aea0ca18cdffce46032d20))
* Bug-fixes in handling of distortions ([`68ce593`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/68ce59394d4db4ca87afe2d18bf85552094fdc77))
* Bug-fix in input file generation ([`4cb5f9b`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/4cb5f9bdcde3a635cc47b79a4165b78d3735a278))
* Correction in sf2ws_spin ([`35d158e`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/35d158e3853146b231f9efb1193f72648eb0343a))
* Improvement in LVC/CFP code ([`d8d040b`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/d8d040b3de0193fa2ddadaa16fe20c297be45931))
* Fix of phasing and block ordering issues ([`adb79b0`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/adb79b024a71a1ebf771e6f6aa37447df975c8a4))

### Breaking
* change in interface ([`c5513de`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/c5513decadd209b8855b3a8f14f65f7912b1273f))

### Documentation
* Pep8 compliance ([`153965a`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/153965a50d9c2547f9178f98e7ecbb106eb86a88))
* Remove incorrect comment about Dy hard coding ([`adde5ce`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/adde5ce0c5de0fbf02131e76afb4a20d7b0d9a46))
* Add missing backtick ([`c653bf2`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/c653bf2c92e017ee46699bcf294d25660c37404c))
* Update readme with new suite installation methods ([`279932b`](https://gitlab.com/chilton-group/spin_phonon_suite/-/commit/279932b6370163f12446f5423c0d3728d4fae9b3))
